/*
 * Copyright (c) 2017, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License, 
 * Version 2.0 (the "License"); you may not use this file except 
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wso2.andes.configuration.models;

import org.wso2.carbon.config.annotation.Configuration;
import org.wso2.carbon.config.annotation.Element;

/**
 * Configuration model for Network partitions detection config in recovery section.
 */
@Configuration(description = "Enables network partition detection ( and surrounding functionality, such\n"
        + "         as disconnecting subscriptions, enabling error based flow control if the\n"
        + "         minimal node count becomes less than configured value.")
public class NetworkPartitionsDetectionConfig {

    @Element(description = "Enable network partition detection.")
    private boolean enabled = false;

    @Element(description = "The minimum node count the cluster should maintain for this node to\n"
            + "                operate. if cluster size becomes less that configured value\n"
            + "                This node will not accept any incoming traffic ( and disconnect\n"
            + "                subscriptions) etc.")
    private int minimumClusterSize = 1;

    public boolean isEnabled() {
        return enabled;
    }

    public int getMinimumClusterSize() {
        return minimumClusterSize;
    }
}